package logic

import (
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"sort"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetDepartmentsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetDepartmentsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetDepartmentsLogic {
	return &GetDepartmentsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *GetDepartmentsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *GetDepartmentsLogic) GetDepartments(req *types.Request, userinfo *auth.UserInfo) (resp *basic.Response) {
	//todo 鉴权 。。。。
	departList, _, err := l.svcCtx.AllModels.LdapDepartment.GetAll(l.ctx, "sort ASC")
	if err != nil {
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr, "获取部门列表失败")
	}
	//变成树形结构
	list := l.DepartmentListToTree(departList)
	return resp.SetStatusWithMessage(basic.CodeOK, "success", types.GetDepartmentsRsp{
		List: list,
	})
}

func (l *GetDepartmentsLogic)DepartmentListToTree(deps []gmodel.LdapDepartment)[]*types.DepartmentsItem{
	//存入map
	mapDepartment := make(map[int64]*types.DepartmentsItem)
	for _, v := range deps {
		mapDepartment[v.Id] = &types.DepartmentsItem{
			Id:        v.Id,
			Name:      *v.Name,
			Remark:    *v.Remark,
			Type:      *v.Type,
			ParentId:  *v.ParentId,
			Dn:        *v.Dn,
			SyncState: *v.SyncState,
			Sort:      *v.Sort,
			Child:     make([]*types.DepartmentsItem, 0, 50),
		}
	}
	//组织从属关系
	for _,v := range mapDepartment{
		//如果有父级
		if parent,ok := mapDepartment[v.ParentId];ok{
			parent.Child = append(parent.Child,v)
			sort.Slice(parent.Child, func(i, j int) bool {
				return parent.Child[i].Sort < parent.Child[j].Sort //升序
			})
		}
	}
	//排序
	list := make([]*types.DepartmentsItem, 0, len(deps))
	for _, v := range deps {
		if *v.ParentId == 0 {
			list = append(list, mapDepartment[v.Id])
		}
	}
	return list
}

