package logic

import (
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"time"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type SaveDepartmentLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSaveDepartmentLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SaveDepartmentLogic {
	return &SaveDepartmentLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *SaveDepartmentLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *SaveDepartmentLogic) SaveDepartment(req *types.SaveDepartmentReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	now := time.Now().UTC()
	data := &gmodel.LdapDepartment{
		Name:      &req.Name,
		Remark:    &req.Remark,
		Type:      &req.Type,
		ParentId:  &req.ParentId,
		Dn:        &req.Dn,
		Sort:      &req.Sort,
		Utime:     &now,
	}
	if req.Id > 0{//更新
		if err := l.svcCtx.AllModels.LdapDepartment.Update(l.ctx,req.Id,data);err != nil{
			logx.Error(err)
			return resp.SetStatusWithMessage(basic.CodeDbSqlErr,"更新失败")
		}
		return resp.SetStatusWithMessage(basic.CodeOK,"更新成功")
	}
	//添加
	data.Ctime = &now
	if err := l.svcCtx.AllModels.LdapDepartment.Create(l.ctx,data);err != nil{
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr,"添加失败")
	}
	return resp.SetStatusWithMessage(basic.CodeOK,"添加成功")
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *SaveDepartmentLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
